/*
Description:
A widget that creates an Alert Dialog Box dynamically along with clickable Flat Buttons.
This Dialog box can come in handy when a user needs to be prompted or double-checked about any action before progressing to the next Route.
The default Implementation of this widget when the user doesn't pass any value to the widget gives an Alert Dialog box along with two buttons 'Yes' or 'No'.

Usage:
The user can pass in Flat Buttons, Title of the Alert and the content that is supposed to be displayed.
The user can also pass on parameters like border radius, padding, shadow elevation etc.
See AlertDialogContents and AlertDialogParameters class definitons for more information.
The user also passes a callback function which is invoked when the Alert Dialog box is used.

   AlertDialogContents alertObj1 = new AlertDialogContents(
      <Widget>[
        FlatButton(
          child: Text("Accept",style: TextStyle(color: Colors.black),),
          onPressed: (){},
        ),
        FlatButton(
          child: Text("Cancel",style: TextStyle(color: Colors.black),),
          onPressed: (){},
        ),
      ],
      "Alert Dialog Box content ",
      Text("Alert Title"),
    );

    AlertDialogParameters alertobj2 = new AlertDialogParameters(shape: RoundedRectangleBorder(
        borderRadius:
        BorderRadius.circular(20.0)),
      backgroundColor: Colors.red,
      elevation: 30,
      contentTextStyle: TextStyle(
          fontSize: 18.0,
          color: Colors.blueGrey),
      height: 500,
      width: 500,
      titleTextStyle: TextStyle(
          fontSize: 18.0,
          color: Colors.white),
    );
    onButtonTap(String s){
      print(s);
    }


    CustomAlertDialog(dialogContent: alertObj1, param: alertobj2, callbackAlert: onButtonTap)

imports: 
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom_AlertDialogs.dart';

Author:
Anubhav Sinha
*/

import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/consts.dart' as cons;

//A widget that creates an Alert Dialog Box dynamically along with clickable Flat Buttons.
//This Dialog box can come in handy when a user needs to be prompted or double-checked about any action before progressing to the next Route.
//The default Implementation of this widget when the user doesn't pass any value to the widget gives an Alert Dialog box along with two buttons 'Yes' or 'No'.
class CustomAlertDialog extends StatefulWidget {
  //class param
  final AlertDialogContents dialogContent;
  //class param
  final AlertDialogParameters param;
  //class param
  final void Function(String) callbackAlert;
  //constructor
  const CustomAlertDialog(
      {Key key, @required this.dialogContent, this.param, this.callbackAlert})
      : super(key: key);
  @override
  _CustomAlertDialogState createState() => _CustomAlertDialogState(
      this.dialogContent, this.param, this.callbackAlert);
}

class _CustomAlertDialogState extends State<CustomAlertDialog> {
  AlertDialogContents dialogContent;
  AlertDialogParameters param;
  Function(String) callbackAlert;
  _CustomAlertDialogState(
    AlertDialogContents dialogContent,
    AlertDialogParameters param,
    Function(String) callbackAlert,
  ) {
    this.param = param;
    this.dialogContent = dialogContent;
    this.callbackAlert = callbackAlert;
  }
  String change = '';
  @override
  Widget build(BuildContext context) {
    if (param != null && dialogContent != null) {
      return Container(
        height: (param.height != null) ? param.height : cons.heightFourHundred,
        width: (param.width != null) ? param.width : cons.heightFourHundred,
        child: AlertDialog(
          title: dialogContent.title,
          content: Text(dialogContent.content),
          actions: dialogContent.buttons,
          shape: (param.shape != null)
              ? param.shape
              : RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(20.0)),
          elevation:
              (param.elevation != null) ? param.elevation : cons.heightThirty,
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : Theme.of(context).dialogBackgroundColor,
          contentTextStyle: (param.contentTextStyle != null)
              ? param.contentTextStyle
              : Theme.of(context).textTheme.bodyText2,
          titleTextStyle: (param.titleTextStyle != null)
              ? param.titleTextStyle
              : Theme.of(context).textTheme.headline5,
        ),
      );
    } //if

    else if (param == null && dialogContent != null) {
      return Container(
        height: cons.heightFourHundred,
        width: cons.heightFourHundred,
        child: AlertDialog(
          title: dialogContent.title,
          content: Text(dialogContent.content),
          actions: dialogContent.buttons,
          shape:
              RoundedRectangleBorder(borderRadius: BorderRadius.circular(20.0)),
          elevation: cons.heightThirty,
          backgroundColor: Theme.of(context).dialogBackgroundColor,
          contentTextStyle: Theme.of(context).textTheme.bodyText2,
          titleTextStyle: Theme.of(context).textTheme.headline5,
        ),
      );
    } else {
      return FractionallySizedBox(
        heightFactor: cons.height_factor1,
        widthFactor: cons.width_factor1,
        child: AlertDialog(
          content: Text(cons.dialogContent),
          actions: [
            FlatButton(
              child: Text(
                cons.DIALOG_BUTTON_T1,
              ),
              onPressed: () {
                return callbackAlert(cons.DIALOG_BUTTON_T1);
              },
            ),
            FlatButton(
              child: Text(
                cons.DIALOG_BUTTON_T2,
                style: TextStyle(color: Theme.of(context).buttonColor),
              ),
              onPressed: () {
                return callbackAlert(cons.DIALOG_BUTTON_T2);
              },
            )
          ],
          backgroundColor: Theme.of(context).dialogBackgroundColor,
          contentTextStyle: TextStyle(
            fontSize: cons.font_size2,
          ),
        ),
      );
    }
  }
}
